anyline_tire_tread_plugin library
Anyline Tire Tread SDK Flutter Plugin
This library provides Flutter bindings for the Anyline Tire Tread SDK, enabling tire tread depth measurement and analysis in Flutter applications.
Features
- Initialize SDK with license key validation
- Scan tire tread depth with customizable UI configuration
- Retrieve measurement results and heatmap visualizations
- Submit feedback comments and tread depth corrections
- Configure experimental features
Usage
final plugin = TireTreadPlugin();
// Initialize with your license key
await plugin.initialize('YOUR_LICENSE_KEY');
// Configure and start scanning
final config = TireTreadConfig()
..scanConfig = (ScanConfig()..tireWidth = 185)
..uiConfig = (UiConfig()
..measurementSystem = MeasurementSystem.Metric
..scanSpeed = ScanSpeed.Fast);
await plugin.scan(config: config);
// Listen for scan events
plugin.onScanningEvent.listen((event) {
if (event is ScanProcessCompleted) {
// Retrieve results
final result = await plugin.getResult(
measurementUUID: event.measurementUUID
);
}
});
Classes
- AdditionalContext
- Provides additional context to a scan. This makes sense in a workflow, where a scan is connected to other TireTread scans or other information in a larger context.
- CountdownConfig
- Configuration for the countdown UI element.
- DistanceIndicatorConfig
- Configuration for the distance indicator UI element.
- ExperimentalFlags
- Placeholder class for experimental feature flags.
- FocusPointTooltipConfig
- Configuration for the focus point tooltip UI element.
- MeasurementInfo
- Metadata about a tire tread measurement.
- MissingPermissionConfig
- Configuration for the missing permission UI element.
- OrientationWarningConfig
- Configuration for the orientation warning UI element.
- ScanAborted
- Event emitted when the user cancels the scanning process.
- ScanConfig
- Configuration for the scanning process.
- ScanDirectionConfig
- Configuration for the scan direction UI element.
- ScanEvent
- Base class for all tire scanning events.
- ScanFailed
- Event emitted when the scanning process fails due to an error.
- ScanProcessCompleted
- Event emitted when the scanning process completes successfully.
- ScanStarted
- Event emitted when tire scanning begins.
- TapToStartScanningTooltipConfig
- Configuration for the tap to start scanning tooltip UI element.
- TireOverlayConfig
- Configuration for the tire overlay UI element.
- TirePosition
-
Position where the tire is mounted on the vehicle, considering the primary direction of travel.
E.g. the front left tire of a passenger car would be specified as
axle=1,side=TireSide.Left,positionOnAxle=1and the rear right tire of a passenger car asaxle=2,side=TireSide.Right,positionOnAxle=1. - TireTreadConfig
- Configuration for tire tread scanning, including UI configuration. This class wraps the TireTreadConfig from the native SDK.
- TireTreadPlugin
- Main entry point for the Anyline Tire Tread SDK Flutter Plugin.
- TireWidthInputConfig
- Configuration for the tire width input UI element.
- TireWidthRange
- Configuration for the allowable tire width range.
- TreadDepthResult
- Represents the complete tread depth measurement result from a tire scan.
- TreadResultRegion
- Represents a tread depth measurement for a specific region or the entire tire.
- UiConfig
- Main UI configuration class that contains all UI-related settings.
- UploadViewConfig
- Configuration for the upload view UI element.
Enums
- Appearance
- Combination of UI and haptic feedback that should be used.
- HeatmapStyle
- The style of the heatmap image.
- MeasurementSystem
- The measurement system to be displayed.
- ScanSpeed
- The speed at which the tire tread scan should be performed.
- TireSide
- The side of the tire on the vehicle.